[ARVADOS] updated: 2.1.0-928-ga858a1537

Git user git at public.arvados.org
Thu Jul 8 20:19:03 UTC 2021


Summary of changes:
 build/version-at-commit.sh                                    | 10 +++++-----
 doc/admin/keep-recovering-data.html.textile.liquid            |  2 +-
 doc/admin/upgrading.html.textile.liquid                       |  2 +-
 doc/install/salt-multi-host.html.textile.liquid               | 11 ++++++-----
 doc/install/salt-single-host.html.textile.liquid              |  2 +-
 doc/install/salt-vagrant.html.textile.liquid                  |  2 +-
 doc/sdk/go/example.html.textile.liquid                        |  2 +-
 doc/user/cwl/cwl-runner.html.textile.liquid                   |  2 +-
 doc/user/cwl/federated-workflows.html.textile.liquid          |  2 +-
 .../test/functional/arvados/v1/job_reuse_controller_test.rb   |  2 +-
 services/arv-git-httpd/server_test.go                         |  6 +++---
 tools/arvbox/lib/arvbox/docker/service/gitolite/run-service   |  2 +-
 .../single_host/multiple_hostnames/states/snakeoil_certs.sls  |  2 +-
 .../single_host/single_hostname/states/snakeoil_certs.sls     |  2 +-
 14 files changed, 25 insertions(+), 24 deletions(-)

       via  a858a15370220c57fc1feb3c6f50655244193e33 (commit)
      from  eeb3cdf88400f542f930fa25a9cf5b5208c4664b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit a858a15370220c57fc1feb3c6f50655244193e33
Author: Ward Vandewege <ward at curii.com>
Date:   Thu Jul 1 14:00:01 2021 -0400

    The bleeding edge branch is now called 'main'.
    
    refs #17817
    
    Arvados-DCO-1.1-Signed-off-by: Ward Vandewege <ward at curii.com>

diff --git a/doc/admin/keep-recovering-data.html.textile.liquid b/doc/admin/keep-recovering-data.html.textile.liquid
index 3a9f51e56..14e25dd11 100644
--- a/doc/admin/keep-recovering-data.html.textile.liquid
+++ b/doc/admin/keep-recovering-data.html.textile.liquid
@@ -106,4 +106,4 @@ For blocks which were trashed long enough ago that they've been deleted, it may
 * Delete the affected collections so that job reuse doesn't attempt to reuse them (it's likely that if one block is missing, they all are, so they're unlikely to contain any useful data)
 * Resubmit any container requests for which you want the output collections regenerated
 
-The Arvados repository contains a tool that can be used to generate a report to help with this task at "arvados/tools/keep-xref/keep-xref.py":https://github.com/arvados/arvados/blob/master/tools/keep-xref/keep-xref.py
+The Arvados repository contains a tool that can be used to generate a report to help with this task at "arvados/tools/keep-xref/keep-xref.py":https://github.com/arvados/arvados/blob/main/tools/keep-xref/keep-xref.py
diff --git a/doc/admin/upgrading.html.textile.liquid b/doc/admin/upgrading.html.textile.liquid
index 86950de24..6067b72e2 100644
--- a/doc/admin/upgrading.html.textile.liquid
+++ b/doc/admin/upgrading.html.textile.liquid
@@ -406,7 +406,7 @@ h2(#v1_3_3). v1.3.3 (2019-05-14)
 
 This release corrects a potential data loss issue, if you are running Arvados 1.3.0 or 1.3.1 we strongly recommended disabling @keep-balance@ until you can upgrade to 1.3.3 or 1.4.0. With keep-balance disabled, there is no chance of data loss.
 
-We've put together a "wiki page":https://dev.arvados.org/projects/arvados/wiki/Recovering_lost_data which outlines how to recover blocks which have been put in the trash, but not yet deleted, as well as how to identify any collections which have missing blocks so that they can be regenerated. The keep-balance component has been enhanced to provide a list of missing blocks and affected collections and we've provided a "utility script":https://github.com/arvados/arvados/blob/master/tools/keep-xref/keep-xref.py  which can be used to identify the workflows that generated those collections and who ran those workflows, so that they can be rerun.
+We've put together a "wiki page":https://dev.arvados.org/projects/arvados/wiki/Recovering_lost_data which outlines how to recover blocks which have been put in the trash, but not yet deleted, as well as how to identify any collections which have missing blocks so that they can be regenerated. The keep-balance component has been enhanced to provide a list of missing blocks and affected collections and we've provided a "utility script":https://github.com/arvados/arvados/blob/main/tools/keep-xref/keep-xref.py  which can be used to identify the workflows that generated those collections and who ran those workflows, so that they can be rerun.
 
 h2(#v1_3_0). v1.3.0 (2018-12-05)
 
diff --git a/doc/install/salt-multi-host.html.textile.liquid b/doc/install/salt-multi-host.html.textile.liquid
index ed57807c7..f17575078 100644
--- a/doc/install/salt-multi-host.html.textile.liquid
+++ b/doc/install/salt-multi-host.html.textile.liquid
@@ -50,17 +50,18 @@ We suggest distributing the Arvados components in the following way, creating at
 
 Note that these hosts can be virtual machines in your infrastructure and they don't need to be physical machines.
 
-h3(#hosts_setup_using_terraform). Hosts setup using terraform (experimental)
+Again, if your infrastructure differs from the setup proposed above (ie, using RDS or an existing DB server), remember that you will need to edit the configuration files for the scripts so they work with your infrastructure.
 
-We added a few "terraform":https://terraform.io/ scripts (https://github.com/arvados/arvados/tree/master/tools/terraform) to let you create these instances easier.
-Check "the Arvados terraform documentation":/doc/install/terraform.html for more details.
+h3(#hosts_setup_using_terraform). Hosts setup using terraform (AWS, experimental)
+
+We added a few "terraform":https://terraform.io/ scripts (https://github.com/arvados/arvados/tree/main/tools/terraform) to let you create these instances easier in an AWS account. Check "the Arvados terraform documentation":/doc/install/terraform.html for more details.
 
 h2(#multi_host). Multi host install using the provision.sh script
 
 {% if site.current_version %}
 {% assign branchname = site.current_version | slice: 1, 5 | append: '-dev' %}
 {% else %}
-{% assign branchname = 'master' %}
+{% assign branchname = 'main' %}
 {% endif %}
 
 This is a package-based installation method. Start with the @provision.sh@ script which is available by cloning the @{{ branchname }}@ branch from "https://git.arvados.org/arvados.git":https://git.arvados.org/arvados.git .  The @provision.sh@ script and its supporting files can be found in the "arvados/tools/salt-install":https://git.arvados.org/arvados.git/tree/refs/heads/{{ branchname }}:/tools/salt-install directory in the Arvados git repository.
@@ -73,7 +74,7 @@ After setting up a few variables in a config file (next step), you'll be ready t
 
 h3(#create_a_compute_image). Create a compute image
 
-In a multi-host installation, containers are dispatched in docker daemons running in the <i>compute instances</i>, which need some special setup. We provide a "compute image builder script":https://github.com/arvados/arvados/tree/master/tools/compute-images that you can use to build a template image following "these instructions":https://doc.arvados.org/main/install/crunch2-cloud/install-compute-node.html . Once you have that image created, you can use the image reference in the Arvados configuration in the next steps.
+In a multi-host installation, containers are dispatched in docker daemons running in the <i>compute instances</i>, which need some special setup. We provide a "compute image builder script":https://github.com/arvados/arvados/tree/main/tools/compute-images that you can use to build a template image following "these instructions":https://doc.arvados.org/main/install/crunch2-cloud/install-compute-node.html . Once you have that image created, you can use the image ID in the Arvados configuration in the next steps.
 
 h2(#choose_configuration). Choose the desired configuration
 
diff --git a/doc/install/salt-single-host.html.textile.liquid b/doc/install/salt-single-host.html.textile.liquid
index 39eb47965..6a066f77b 100644
--- a/doc/install/salt-single-host.html.textile.liquid
+++ b/doc/install/salt-single-host.html.textile.liquid
@@ -28,7 +28,7 @@ h2(#single_host). Single host install using the provision.sh script
 {% if site.current_version %}
 {% assign branchname = site.current_version | slice: 1, 5 | append: '-dev' %}
 {% else %}
-{% assign branchname = 'master' %}
+{% assign branchname = 'main' %}
 {% endif %}
 
 This is a package-based installation method. Start with the @provision.sh@ script which is available by cloning the @{{ branchname }}@ branch from "https://git.arvados.org/arvados.git":https://git.arvados.org/arvados.git .  The @provision.sh@ script and its supporting files can be found in the "arvados/tools/salt-install":https://git.arvados.org/arvados.git/tree/refs/heads/{{ branchname }}:/tools/salt-install directory in the Arvados git repository.
diff --git a/doc/install/salt-vagrant.html.textile.liquid b/doc/install/salt-vagrant.html.textile.liquid
index c913e2041..8ba4b324e 100644
--- a/doc/install/salt-vagrant.html.textile.liquid
+++ b/doc/install/salt-vagrant.html.textile.liquid
@@ -18,7 +18,7 @@ SPDX-License-Identifier: CC-BY-SA-3.0
 
 h2(#vagrant). Vagrant
 
-This is a package-based installation method. The Salt scripts are available from the "tools/salt-install":https://github.com/arvados/arvados/tree/master/tools/salt-install directory in the Arvados git repository.
+This is a package-based installation method. The Salt scripts are available from the "tools/salt-install":https://github.com/arvados/arvados/tree/main/tools/salt-install directory in the Arvados git repository.
 
 A @Vagrantfile@ is provided to install Arvados in a virtual machine on your computer using "Vagrant":https://www.vagrantup.com/.
 
diff --git a/doc/sdk/go/example.html.textile.liquid b/doc/sdk/go/example.html.textile.liquid
index 688c45bf3..031791fde 100644
--- a/doc/sdk/go/example.html.textile.liquid
+++ b/doc/sdk/go/example.html.textile.liquid
@@ -78,4 +78,4 @@ You can save this source as a .go file and run it:
 
 <notextile>{% code example_sdk_go as go %}</notextile>
 
-A few more usage examples can be found in the "services/keepproxy":https://dev.arvados.org/projects/arvados/repository/revisions/master/show/services/keepproxy and "sdk/go/keepclient":https://dev.arvados.org/projects/arvados/repository/revisions/master/show/sdk/go/keepclient directories in the arvados source tree.
+A few more usage examples can be found in the "services/keepproxy":https://dev.arvados.org/projects/arvados/repository/revisions/main/show/services/keepproxy and "sdk/go/keepclient":https://dev.arvados.org/projects/arvados/repository/revisions/main/show/sdk/go/keepclient directories in the arvados source tree.
diff --git a/doc/user/cwl/cwl-runner.html.textile.liquid b/doc/user/cwl/cwl-runner.html.textile.liquid
index 442a60b04..b108de551 100644
--- a/doc/user/cwl/cwl-runner.html.textile.liquid
+++ b/doc/user/cwl/cwl-runner.html.textile.liquid
@@ -22,7 +22,7 @@ This tutorial will demonstrate how to submit a workflow at the command line usin
 
 h2(#get-files). Get the tutorial files
 
-The tutorial files are located in the documentation section of the Arvados source repository, which can be found on "git.arvados.org":https://git.arvados.org/arvados.git/tree/HEAD:/doc/user/cwl/bwa-mem or "github":https://github.com/arvados/arvados/tree/master/doc/user/cwl/bwa-mem
+The tutorial files are located in the documentation section of the Arvados source repository, which can be found on "git.arvados.org":https://git.arvados.org/arvados.git/tree/HEAD:/doc/user/cwl/bwa-mem or "github":https://github.com/arvados/arvados/tree/main/doc/user/cwl/bwa-mem
 
 <notextile>
 <pre><code>~$ <span class="userinput">git clone https://git.arvados.org/arvados.git</span>
diff --git a/doc/user/cwl/federated-workflows.html.textile.liquid b/doc/user/cwl/federated-workflows.html.textile.liquid
index bf5f1fc05..a93aac56b 100644
--- a/doc/user/cwl/federated-workflows.html.textile.liquid
+++ b/doc/user/cwl/federated-workflows.html.textile.liquid
@@ -17,7 +17,7 @@ For more information, visit the "architecture":{{site.baseurl}}/architecture/fed
 
 h2. Get the example files
 
-The tutorial files are located in the "documentation section of the Arvados source repository:":https://github.com/arvados/arvados/tree/master/doc/user/cwl/federated or "see below":#fed-example
+The tutorial files are located in the "documentation section of the Arvados source repository:":https://github.com/arvados/arvados/tree/main/doc/user/cwl/federated or "see below":#fed-example
 
 <notextile>
 <pre><code>~$ <span class="userinput">git clone https://github.com/arvados/arvados</span>
diff --git a/services/api/test/functional/arvados/v1/job_reuse_controller_test.rb b/services/api/test/functional/arvados/v1/job_reuse_controller_test.rb
index 02c5c6892..46cfac5c9 100644
--- a/services/api/test/functional/arvados/v1/job_reuse_controller_test.rb
+++ b/services/api/test/functional/arvados/v1/job_reuse_controller_test.rb
@@ -16,7 +16,7 @@ class Arvados::V1::JobReuseControllerTest < ActionController::TestCase
   BASE_FILTERS = {
     'repository' => ['=', 'active/foo'],
     'script' => ['=', 'hash'],
-    'script_version' => ['in git', 'master'],
+    'script_version' => ['in git', 'main'],
     'docker_image_locator' => ['=', nil],
     'arvados_sdk_version' => ['=', nil],
   }
diff --git a/services/arv-git-httpd/server_test.go b/services/arv-git-httpd/server_test.go
index cba82fe3f..386205d37 100644
--- a/services/arv-git-httpd/server_test.go
+++ b/services/arv-git-httpd/server_test.go
@@ -39,7 +39,7 @@ func (s *GitSuite) TestPathVariants(c *check.C) {
 func (s *GitSuite) TestReadonly(c *check.C) {
 	err := s.RunGit(c, spectatorToken, "fetch", "active/foo.git")
 	c.Assert(err, check.Equals, nil)
-	err = s.RunGit(c, spectatorToken, "push", "active/foo.git", "master:newbranchfail")
+	err = s.RunGit(c, spectatorToken, "push", "active/foo.git", "main:newbranchfail")
 	c.Assert(err, check.ErrorMatches, `.*HTTP (code = )?403.*`)
 	_, err = os.Stat(s.tmpRepoRoot + "/zzzzz-s0uqq-382brsig8rp3666.git/refs/heads/newbranchfail")
 	c.Assert(err, check.FitsTypeOf, &os.PathError{})
@@ -48,7 +48,7 @@ func (s *GitSuite) TestReadonly(c *check.C) {
 func (s *GitSuite) TestReadwrite(c *check.C) {
 	err := s.RunGit(c, activeToken, "fetch", "active/foo.git")
 	c.Assert(err, check.Equals, nil)
-	err = s.RunGit(c, activeToken, "push", "active/foo.git", "master:newbranch")
+	err = s.RunGit(c, activeToken, "push", "active/foo.git", "main:newbranch")
 	c.Assert(err, check.Equals, nil)
 	_, err = os.Stat(s.tmpRepoRoot + "/zzzzz-s0uqq-382brsig8rp3666.git/refs/heads/newbranch")
 	c.Assert(err, check.Equals, nil)
@@ -104,7 +104,7 @@ func (s *GitSuite) makeArvadosRepo(c *check.C) {
 	msg, err := exec.Command("git", "init", "--bare", s.tmpRepoRoot+"/zzzzz-s0uqq-arvadosrepo0123.git").CombinedOutput()
 	c.Log(string(msg))
 	c.Assert(err, check.Equals, nil)
-	msg, err = exec.Command("git", "--git-dir", s.tmpRepoRoot+"/zzzzz-s0uqq-arvadosrepo0123.git", "fetch", "../../.git", "HEAD:master").CombinedOutput()
+	msg, err = exec.Command("git", "--git-dir", s.tmpRepoRoot+"/zzzzz-s0uqq-arvadosrepo0123.git", "fetch", "../../.git", "HEAD:main").CombinedOutput()
 	c.Log(string(msg))
 	c.Assert(err, check.Equals, nil)
 }
diff --git a/tools/arvbox/lib/arvbox/docker/service/gitolite/run-service b/tools/arvbox/lib/arvbox/docker/service/gitolite/run-service
index c60c15bfc..698367b8a 100755
--- a/tools/arvbox/lib/arvbox/docker/service/gitolite/run-service
+++ b/tools/arvbox/lib/arvbox/docker/service/gitolite/run-service
@@ -101,7 +101,7 @@ fi
 if ! test -d $ARVADOS_CONTAINER_PATH/git/repositories/$repo_uuid.git ; then
     git clone --bare /usr/src/arvados $ARVADOS_CONTAINER_PATH/git/repositories/$repo_uuid.git
 else
-    git --git-dir=$ARVADOS_CONTAINER_PATH/git/repositories/$repo_uuid.git fetch -f /usr/src/arvados master:master
+    git --git-dir=$ARVADOS_CONTAINER_PATH/git/repositories/$repo_uuid.git fetch -f /usr/src/arvados main:main
 fi
 
 cd /usr/src/arvados/services/api
diff --git a/tools/salt-install/config_examples/single_host/multiple_hostnames/states/snakeoil_certs.sls b/tools/salt-install/config_examples/single_host/multiple_hostnames/states/snakeoil_certs.sls
index 466d41d42..fb1473def 100644
--- a/tools/salt-install/config_examples/single_host/multiple_hostnames/states/snakeoil_certs.sls
+++ b/tools/salt-install/config_examples/single_host/multiple_hostnames/states/snakeoil_certs.sls
@@ -30,7 +30,7 @@ arvados_test_salt_states_examples_single_host_snakeoil_certs_dependencies_pkg_in
       - ca-certificates
 
 arvados_test_salt_states_examples_single_host_snakeoil_certs_arvados_snake_oil_ca_cmd_run:
-  # Taken from https://github.com/arvados/arvados/blob/master/tools/arvbox/lib/arvbox/docker/service/certificate/run
+  # Taken from https://github.com/arvados/arvados/blob/main/tools/arvbox/lib/arvbox/docker/service/certificate/run
   cmd.run:
     - name: |
         # These dirs are not to CentOS-ish, but this is a helper script
diff --git a/tools/salt-install/config_examples/single_host/single_hostname/states/snakeoil_certs.sls b/tools/salt-install/config_examples/single_host/single_hostname/states/snakeoil_certs.sls
index d88adbc53..130fb5e93 100644
--- a/tools/salt-install/config_examples/single_host/single_hostname/states/snakeoil_certs.sls
+++ b/tools/salt-install/config_examples/single_host/single_hostname/states/snakeoil_certs.sls
@@ -30,7 +30,7 @@ arvados_test_salt_states_examples_single_host_snakeoil_certs_dependencies_pkg_in
       - ca-certificates
 
 arvados_test_salt_states_examples_single_host_snakeoil_certs_arvados_snake_oil_ca_cmd_run:
-  # Taken from https://github.com/arvados/arvados/blob/master/tools/arvbox/lib/arvbox/docker/service/certificate/run
+  # Taken from https://github.com/arvados/arvados/blob/main/tools/arvbox/lib/arvbox/docker/service/certificate/run
   cmd.run:
     - name: |
         # These dirs are not to CentOS-ish, but this is a helper script

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/build/version-at-commit.sh b/build/version-at-commit.sh
index 53687dafe..1ffea34fa 100755
--- a/build/version-at-commit.sh
+++ b/build/version-at-commit.sh
@@ -14,12 +14,12 @@ devsuffix="~dev"
 #
 # 1. commit is directly tagged.  print that.
 #
 # 2. commit is on master or a development branch, the nearest tag is older
 #    than commit where this branch joins master.
 #    -> take greatest version tag in repo X.Y.Z and assign X.(Y+1).0
 #
 # 3. commit is on a release branch, the nearest tag is newer
 #    than the commit where this branch joins master.
 #    -> take nearest tag X.Y.Z and assign X.Y.(Z+1)
 
 tagged=$(git tag --points-at "$commit")
@@ -28,13 +28,13 @@ if [[ -n "$tagged" ]] ; then
     echo $tagged
 else
     # 1. get the nearest tag with 'git describe'
     # 2. get the merge base between this commit and master
     # 3. if the tag is an ancestor of the merge base,
     #    (tag is older than merge base) increment minor version
     #    else, tag is newer than merge base, so increment point version
 
     nearest_tag=$(git describe --tags --abbrev=0 --match "$versionglob" "$commit")
-    merge_base=$(git merge-base origin/master "$commit")
+    merge_base=$(git merge-base origin/main "$commit")
 
     if git merge-base --is-ancestor "$nearest_tag" "$merge_base" ; then
         # x.(y+1).0.devTIMESTAMP, where x.y.z is the newest version that does not contain $commit
@@ -14,12 +14,12 @@ devsuffix="~dev"
 # 1. commit is directly tagged.  print that.
 #
-# 2. commit is on master or a development branch, the nearest tag is older
-#    than commit where this branch joins master.
+# 2. commit is on main or a development branch, the nearest tag is older
+#    than commit where this branch joins main.
 #    -> take greatest version tag in repo X.Y.Z and assign X.(Y+1).0
 #
@@ -14,12 +14,12 @@ devsuffix="~dev"
 #
 # 3. commit is on a release branch, the nearest tag is newer
-#    than the commit where this branch joins master.
+#    than the commit where this branch joins main.
 #    -> take nearest tag X.Y.Z and assign X.Y.(Z+1)
 
@@ -28,13 +28,13 @@ if [[ -n "$tagged" ]] ; then
 else
     # 1. get the nearest tag with 'git describe'
-    # 2. get the merge base between this commit and master
+    # 2. get the merge base between this commit and main
     # 3. if the tag is an ancestor of the merge base,
     #    (tag is older than merge base) increment minor version
-- 




More information about the arvados-commits mailing list